[Mulgara-svn] r512 - branches/nw-interface/src/jar/itql/java/org/mulgara/itql

pag at mulgara.org pag at mulgara.org
Mon Nov 5 04:38:31 UTC 2007


Author: pag
Date: 2007-11-04 22:38:30 -0600 (Sun, 04 Nov 2007)
New Revision: 512

Modified:
   branches/nw-interface/src/jar/itql/java/org/mulgara/itql/ItqlInterpreterBean.java
Log:
Report an error if unable to create a session for a URI

Modified: branches/nw-interface/src/jar/itql/java/org/mulgara/itql/ItqlInterpreterBean.java
===================================================================
--- branches/nw-interface/src/jar/itql/java/org/mulgara/itql/ItqlInterpreterBean.java	2007-11-02 21:16:44 UTC (rev 511)
+++ branches/nw-interface/src/jar/itql/java/org/mulgara/itql/ItqlInterpreterBean.java	2007-11-05 04:38:30 UTC (rev 512)
@@ -259,12 +259,14 @@
    * @deprecated The user should not be accessing a session through a
    * command interpreter.
    * @param serverURI URI Server to get a Session for.
    * @return the session to use to communicate with the specified Mulgara server
    */
   public Session getSession(URI serverURI) {
     try {
       return interpreter.establishConnection(serverURI).getSession();
     } catch (Exception e) {
+      log.error("Unable to get session for: " + serverURI, e);
       return null;
     }
   }
@@ -259,12 +259,14 @@
    * command interpreter.
    * @param serverURI URI Server to get a Session for.
-   * @return the session to use to communicate with the specified Mulgara server
+   * @return the session to use to communicate with the specified Mulgara server,
+   * or <code>null</code> if it was not possible to create a session for the URI.
    */
   public Session getSession(URI serverURI) {




More information about the Mulgara-svn mailing list